@@ -99,6 +99,10 @@ sim_quantile_other <- function(tb, fit, p, name, yhatName, nSims){
     sim_response <- get_sim_response(tb, fit, nSims)
     quants <- apply(sim_response, 1, FUN = quantile, probs = p, type = 1)
 
+    if(fit$family$family == "binomial"){
+      out <- out * fit$prior.weights
+      warning("For binomial models, add_quantile's column of fitted values reflect E(Y|X) rather than typical default for logistic regression, pHat")
+    }
     if(is.null(tb[[yhatName]]))
         tb[[yhatName]] <- out
     tb[[name]] <- quants
